==> jc-1.4.0.tar.gz: soot/Transformer.h <==
// public abstract class soot.Transformer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Transformer_H_
#define _JC_soot_Transformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_Transformer$sub_refs	_jc_soot_Transformer$sub_refs;
typedef struct _jc_soot_Transformer$sub_nonrefs	_jc_soot_Transformer$sub_nonrefs;
typedef struct _jc_soot_Transformer$refs	_jc_soot_Transformer$refs;
typedef struct _jc_soot_Transformer$nonrefs	_jc_soot_Transformer$nonrefs;
typedef struct _jc_soot_Transformer$object	_jc_soot_Transformer$object;

typedef const struct _jc_soot_Transformer$vmethods	_jc_soot_Transformer$vmethods;
typedef const struct _jc_soot_Transformer$vtable	_jc_soot_Transformer$vtable;
typedef const struct _jc_soot_Transformer$vtype	_jc_soot_Transformer$vtype;

// Constructors
extern void _jc_soot_Transformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_Transformer$object *);

// Virtual methods structure
struct _jc_soot_Transformer$vmethods {
};

// Vtable
struct _jc_soot_Transformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
};

// Vtype
struct _jc_soot_Transformer$vtype {
	_jc_type			type;
	_jc_soot_Transformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Transformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_Transformer$refs {
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Transformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_Transformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
};

// Object instance structure
struct _jc_soot_Transformer$object {
	_jc_soot_Transformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Transformer$vtype	*vtype;
	_jc_soot_Transformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Transformer$vtype _jc_soot_Transformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Transformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Transformer$class_object;

#endif	/* _JC_soot_Transformer_H_ */

==> jc-1.4.6.tar.gz: soot/Transformer.h <==
// public abstract class soot.Transformer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class de5fa3182955e270 soot_Transformer

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_Transformer_H_
#define _JC_soot_Transformer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_Transformer$sub_refs	_jc_soot_Transformer$sub_refs;
typedef struct _jc_soot_Transformer$sub_nonrefs	_jc_soot_Transformer$sub_nonrefs;
typedef struct _jc_soot_Transformer$refs	_jc_soot_Transformer$refs;
typedef struct _jc_soot_Transformer$nonrefs	_jc_soot_Transformer$nonrefs;
typedef struct _jc_soot_Transformer$object	_jc_soot_Transformer$object;

typedef const struct _jc_soot_Transformer$vmethods	_jc_soot_Transformer$vmethods;
typedef const struct _jc_soot_Transformer$vtable	_jc_soot_Transformer$vtable;
typedef const struct _jc_soot_Transformer$vtype	_jc_soot_Transformer$vtype;

// Constructors
extern void _jc_soot_Transformer$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_Transformer$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_Transformer$vmethods {
};

// Vtable
struct _jc_soot_Transformer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
};

// Vtype
struct _jc_soot_Transformer$vtype {
	_jc_type			type;
	_jc_soot_Transformer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_Transformer$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_Transformer$refs {
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_Transformer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_Transformer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
};

// Object instance structure
struct _jc_soot_Transformer$object {
	_jc_soot_Transformer$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_Transformer$vtype	*vtype;
	_jc_soot_Transformer$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_Transformer$vtype _jc_soot_Transformer$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_Transformer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_Transformer$class_object;

#endif	/* _JC_soot_Transformer_H_ */
